=========
OQToolsUI
=========

OQToolsUI is a GUI application for generating openquake hazard config files.

------------
Installation
------------
You can install OQToolsUI with::

 pip install OQToolsUI